//
//  LottoData.m
//

#import "LottoData.h"

@implementation LottoData

// Convenience class methods that return an initialized and autoreleased object
+ (LottoData *)lottoData {
    return [[[self alloc] init] autorelease];
}

+ (LottoData *)lottoDataWithCount:(int)count {
    return [[[self alloc] initWithCount:count] autorelease];
}

// Override init, see Hillegass: Cocoa Programming, p.67
- (id)init
{
    return [self initWithCount:35];
}

// Designated initializer that takes the parameter count
- (id)initWithCount:(int)count
{
    int i;
    NSNumber *number;

    if ( self = [super init] ) {
        // seed the random number generator
        srandom(time(NULL));
        
        // create an array to hold the numbers
        numbers = [[NSMutableArray alloc] init];

        // fill it with 'count' sequental numbers, starting at zero
        for ( i = 0; i < count; i++ ) {
            number = [[NSNumber alloc] initWithInt:i];
            [numbers addObject:number];
            [number release];
        }
    }
    return self;
}

// Shuffle all the numbers in the array
- (void)randomize {
    int i;
    int n = [numbers count];

    for ( i = 0; i < n; i++ ) {
        [numbers exchangeObjectAtIndex:i withObjectAtIndex:(random() % n)];
    }
}

// Accessor methods
- (NSMutableArray *)numbers {
    return numbers;
}

/* These methods are not required by this implementation of Lotto
- (void)setNumbers:(NSMutableArray *)array {
    [array retain];
    [numbers release];
    numbers = array;

    NSLog(@"LottoData 'numbers' setCount: %d", [numbers retainCount]);
}

- (void)dealloc
{
    NSLog(@"Destroying Data %@", self);
    [self setNumbers:nil]; // numbers is released in set method
    [super dealloc];
}
*/

// NSObject method that can be used for debugging with 'po' command in GDB
// This method is used when NSLog() describes the object %@
// It could also be used in a GUI status display; Cocoa Dev Central: All Purpose App
- (NSString *)description
{
    return [NSString stringWithFormat:@"Array with %d numbers: %@", [numbers count], numbers];
}

@end
