//
// LottoView.m
//
// Changes Dec 2002: Removed incorrect -isOpaque. Cleaned up -drawRect.

#import "LottoView.h"
#import "LottoData.h"

@implementation LottoView

/* Designated initializer for NSControl (and NSView). However, since the imageview LottoView is unarchived from a nib, it would have required the use of -awakeFromNib instead.
- (id)initWithFrame:(NSRect)rect
{
    if ( !(self = [super initWithFrame:rect]) ) return nil;
    return self;
} */

// Override NSView method
- (void)drawRect:(NSRect)rect
{
    // adjust the supplied view rect
    NSRect canvas = NSInsetRect(rect, 8, 8);
    NSImage *lotto;

    [super drawRect:rect]; // draw the frame & imageview

    // create a new image, draw the masks, and xor on the imageview
    lotto = [[NSImage allocWithZone:[self zone]] initWithSize:canvas.size];
    [lotto lockFocus];
    [[NSColor blackColor] set];
    [self drawMask]; // draw 7 black squares
    [[self image] compositeToPoint:NSZeroPoint operation:NSCompositeXOR];
    [lotto unlockFocus];

    // hide the imageview - create a clean canvas
    NSEraseRect(canvas);

    // draw the transparent composite image (this method ignores scaling & rotating, use drawAtPoint:fromRect:operation:fraction if these are required)
    [lotto compositeToPoint:canvas.origin operation:NSCompositeSourceOver];

    [lotto release]; // don't need this object anymore
}

- (void)drawMask
{
    int i, n;

    for ( i = 0; i < 7; i++ ) {
        n = [[[[self data] numbers] objectAtIndex:i] intValue];
        [NSBezierPath fillRect:NSMakeRect((n % 6 * 15) + 7, 82 - (n / 6 * 15), 11, 11)];
    }
}

// Accessor methods
- (LottoData *)data {
    return data;
}

- (void)setData:(LottoData *)newData {
    [newData retain]; // retain an entity object (array)
    [data release];
    data = newData;
}

// Not really needed
- (void)dealloc
{
    NSLog(@"Destroying View %@", self);
    [data release];
    [super dealloc];
}

@end
